# django-gesha

[![Test](https://github.com/ely-as/django-gesha/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/ely-as/django-gesha/actions/workflows/test.yml)
[![Version](https://img.shields.io/pypi/v/django-gesha)](https://pypi.org/project/django-gesha/)
![Python](https://img.shields.io/pypi/pyversions/django-gesha)
![Django](https://img.shields.io/pypi/djversions/django-gesha)

---

JavaScript utilities for [Django](https://www.djangoproject.com/) projects.

---

**Features:**

  - [Add context](user_guide/#add-context) in Django views to be used in JavaScript
    functions.
  - [Reverse URLs](user_guide/#reverse-urls) natively in JavaScript (equivalent to
    `#!py reverse()` in Python and `#!django {% url %}` in templates).
  - Written in TypeScript and fully-typed Python.

---

[**Documentation**](https://django-gesha.readthedocs.io/en/latest/)
**&nbsp;•&nbsp;**
[**Issue Tracker**](https://github.com/ely-as/django-gesha/issues)
**&nbsp;•&nbsp;**
[**Source**](https://github.com/ely-as/django-gesha)
